summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--src/util/k5test.py9
1 files changed, 5 insertions, 4 deletions
diff --git a/src/util/k5test.py b/src/util/k5test.py
index dbac717813..8abac02f9f 100644
--- a/src/util/k5test.py
+++ b/src/util/k5test.py
@@ -222,8 +222,9 @@ Scripts may use the following realm methods and attributes:
* realm.create_kdb(): Create a new master KDB.
* realm.start_kdc(): Start a krb5kdc with the realm's master KDC
environment. Errors if a KDC is already running.
* realm.stop_kdc(): Stop the krb5kdc process. Errors if no KDC is
running.
@@ -818,10 +819,10 @@ class K5Realm(object):
global kdb5_util
self.run_as_master([kdb5_util, 'create', '-W', '-s', '-P', 'master'])
- def start_kdc(self):
+ def start_kdc(self, args=[]):
global krb5kdc
assert(self._kdc_proc is None)
- self._kdc_proc = _start_daemon([krb5kdc, '-n'], self.env_master,
+ self._kdc_proc = _start_daemon([krb5kdc, '-n'] + args, self.env_master,
'starting...')
def stop_kdc(self):
@@ -222,8 +222,9 @@ Scripts may use the following realm methods and attributes:
* realm.create_kdb(): Create a new master KDB.
-* realm.start_kdc(): Start a krb5kdc with the realm's master KDC
- environment. Errors if a KDC is already running.
+* realm.start_kdc(args=[]): Start a krb5kdc with the realm's master
+ KDC environment. Errors if a KDC is already running. If args is
+ given, it contains a list of additional krb5kdc arguments.
* realm.stop_kdc(): Stop the krb5kdc process. Errors if no KDC is
running.